    # -*- coding: utf-8 -*-
#==========================================================#
#Last Updated - March 2018
#@author: z5025317 Valentin Heimhuber
#code for creating future climate variability deviation plots for NARCLIM variables. 
#Inputs: Uses CSV files that containthe deltas of all 12 NARCLIM models for 1 grid cell at the site of interest, generated with P1_NARCLIM_plots_Windows.py
#This code is used only for the NARCLIM variables - a separate code is used for ocean variables etc that are not part of the NARCLIM ensemble

#==========================================================#
#Load packages
#==========================================================#
import numpy as np
import os
import pandas as pd
import glob
import matplotlib
import matplotlib.pyplot as plt
from datetime import datetime
from datetime import timedelta
from matplotlib.backends.backend_pdf import PdfPages
from ggplot import *
import csv
matplotlib.style.use('ggplot')
# Load my own functions
os.chdir('C:/Users/z5025317/OneDrive - UNSW/WRL_Postdoc_Manual_Backup/WRL_Postdoc/Projects/Paper#1/Analysis/Code')
import climdata_fcts as fct
import silo as sil
#==========================================================#

#==========================================================#
# Set working direcotry (where postprocessed NARClIM data is located)
os.chdir('C:/Users/z5025317/OneDrive - UNSW/WRL_Postdoc_Manual_Backup/WRL_Postdoc/Projects/Paper#1/')
#==========================================================#
     
#loop through case study estuaries    
Estuaries = ['HUNTER', 'RICHMOND', 'NADGEE', 'SHOALHAVEN', 'GEORGES','CATHIE']
Estuaries = ['NADGEE','HUNTER', 'RICHMOND']

for Est in Estuaries:
    
    #==========================================================#
    #set input parameters
    #==========================================================#
    Case_Study_Name = 'CASESTUDY2' 
    Version = "V4"
    OutVersion = "V4"
    Casestudy2_csv_path =  'Data/NARCLIM_Site_CSVs/' + Case_Study_Name + '/' + Case_Study_Name + '_NARCLIM_Point_Sites.csv'
    #Estuary = 'HUNTER' # 'Belongil'
    Estuary = Est # 'Belongil'
    print Estuary
    Base_period_start = '1950-01-01'        #Start of interval for base period of climate variability
    Base_period_DELTA_start = '1990-01-01'   #Start of interval used for calculating mean and SD for base period (Delta base period)
    Base_period_end = '2009-01-01'          #use last day that's not included in period as < is used for subsetting
    Clim_var_type  = 'pracc'            #Name of climate variable in NARCLIM models  '*' will create pdf for all variables in folder
    Stats = 'days_h_20'                  #'maxdaily' #maximum takes the annual max Precipitation instead of the sum 'days_h_30'
    
    PD_Datasource = 'SILO'                  #Source for present day climate data (historic time series) can be either: 'Station' or 'SILO'
    SILO_Clim_var = ['daily_rain']         #select the SILO clim variable to be used for base period. - see silo.py for detailed descriptions
    force_sea_levels = 'no'        #use fort denison sea levels to run the statistics
    Location = 'Estuary'                 # pick locaiton for extracting the SILO data can be: Estuary, Catchment, or Ocean
    
    Main_Plot = 'yes'
    presentdaybar = False               #include a bar for present day variability in the plots?
    present_day_plot = 'no'             #save a time series of present day  
    Allin1_delta_plot = 'yes'
    Deltaxmin, Deltaymin = -20,40   #y limits for 0 baseline delta plots
    Median_markers = 'yes'              #plot the median horizontal lines on top of the delta range in the allin1 plot?      
    Figure_headings = 'yes'
    ALPHA_figs = 0                     #Set alpha of figure background (0 makes everything around the plot panel transparent)
    font = {'family' : 'sans-serif',        
        'weight' : 'normal',
        'size'   : 14}                  #size of axis labels
    matplotlib.rc('font', **font)       
    #==========================================================#
    
    
    #==========================================================#
    #set directory path for output files
    output_directory = 'Output/' + Case_Study_Name + '_' + OutVersion + '/' + Estuary + '/' + '/Clim_Deviation_Plots/'
    #output_directory = 'J:/Project wrl2016032/NARCLIM_Raw_Data/Extracted'
    if not os.path.exists(output_directory):
        os.makedirs(output_directory)
        print('-------------------------------------------')
        print("output directory folder didn't exist and was generated")
        print('-------------------------------------------')
        print('-------------------')
    #==========================================================#
    
    
    #==========================================================#
    #read CSV file  
    #==========================================================#
    Clim_Var_CSVs = glob.glob('./Output/' + Case_Study_Name + '_' + Version + '/'  + Estuary + '/' + Estuary + '_' + Clim_var_type + '_' + Stats + '*')
    clim_var_csv_path = Clim_Var_CSVs[0]
    Filename = os.path.basename(os.path.normpath(clim_var_csv_path))
    Clim_var_type = Filename.split('_', 2)[1]
    print(Clim_var_type)
    Ensemble_Delta_full_df = pd.read_csv(clim_var_csv_path, index_col=0, parse_dates = True)
    
    if Clim_var_type == 'rsdsmean':
        Clim_Var_CSVs = glob.glob('./Output/' + Case_Study_Name + '/'  + Estuary + '/' + Estuary + '_rsdsmean_' + Stats + '*')
        clim_var_csv_path = Clim_Var_CSVs[0]
        Filename = os.path.basename(os.path.normpath(clim_var_csv_path))
        Clim_var_type = Filename.split('_', 2)[1]
        print(Clim_var_type)
        Ensemble_Delta_full_df1 = pd.read_csv(clim_var_csv_path, index_col=0, parse_dates = True)
        Clim_Var_CSVs = glob.glob('./Output/' + Case_Study_Name + '/'  + Estuary + '/' + Estuary + '_rldsmean_' + Stats + '*')
        clim_var_csv_path = Clim_Var_CSVs[0]
        Filename = os.path.basename(os.path.normpath(clim_var_csv_path))
        Clim_var_type = Filename.split('_', 2)[1]
        print(Clim_var_type)
        Ensemble_Delta_full_df2 = pd.read_csv(clim_var_csv_path, index_col=0, parse_dates = True)
        Ensemble_Delta_full_df = Ensemble_Delta_full_df2 + Ensemble_Delta_full_df1
    #Ensemble_Delta_full_df = pd.to_numeric(Ensemble_Delta_full_df)
    #==========================================================# 
    
    
    #==========================================================#
    #load present day climate variable time series
    #==========================================================#
    if PD_Datasource == 'Station':
        Present_day_df,minplotDelta, maxplotDelta = fct.import_present_day_climdata_csv(Estuary, Clim_var_type)
    
        if force_sea_levels == 'yes':
            Estuary_Folder = "C:/Users/z5025317/OneDrive - UNSW/WRL_Postdoc_Manual_Backup/WRL_Postdoc/Projects/Paper#1/Data/Ocean_Data/Tide_Levels"
            Present_day_df = pd.read_csv(Estuary_Folder + '/Fort_Denison_Daily_1900-2011.csv' , parse_dates=True, index_col=0)
            Present_day_df = pd.read_csv(Estuary_Folder + '/Fort_Denison_Daily_1900-2011.csv' , parse_dates=True, index_col=0)
            Present_day_df = Present_day_df.interpolate()
            Present_day_df = pd.DataFrame(Present_day_df.loc[(Present_day_df.index >= Base_period_start) & (Present_day_df.index <= Base_period_end)])
            [minplotDelta, maxplotDelta]=[1, 1]
            
            df = pd.read_csv(Estuary_Folder + '/Fort_Denison_Sub_Daily_1900-2011.csv',  parse_dates=[['Date', 'Time']])
            df.index = pd.to_datetime(df.Date, format = 'dd/mm/Y') + pd.to_timedelta(df.Hour, unit='h')
        
    if PD_Datasource == 'SILO':
        #read the CSV to extract the lat long and case stuy sites
        with open(Casestudy2_csv_path, mode='r') as infile:
            reader = csv.reader(infile)
            next(reader, None) 
            with open('coors_new.csv', mode='w') as outfile:
                writer = csv.writer(outfile)
                if Location == 'Estuary':
                    mydict = dict((rows[0],[rows[1],rows[2]]) for rows in reader)
                if Location == 'Ocean':
                    mydict = dict((rows[0],[rows[3],rows[4]]) for rows in reader)
                if Location == 'Catchment':
                    mydict = dict((rows[0],[rows[5],rows[6]]) for rows in reader)
                
        if Clim_var_type == 'tasmean':
            silo_df = sil.pointdata(["max_temp", "min_temp"], 'Okl9EDxgS2uzjLWtVNIBM5YqwvVcCxOmpd3nCzJh', Base_period_start.replace("-", ""), Base_period_end.replace("-", ""), 
                                        None, mydict[Estuary][0], mydict[Estuary][1], False, None)
            #take mean of daily min and max temp
            Present_day_df =     silo_df.iloc[:,[2,4]].mean(axis=1)
        else:
            silo_df = sil.pointdata(SILO_Clim_var, 'Okl9EDxgS2uzjLWtVNIBM5YqwvVcCxOmpd3nCzJh', Base_period_start.replace("-", ""), Base_period_end.replace("-", ""), 
                                        None, mydict[Estuary][0], mydict[Estuary][1], False, None)
            Present_day_df = silo_df.iloc[:,[2]]
    
        #set the x and y limit deltas -  for plotting only
        if Clim_var_type in ['evspsblmean', 'potevpmean']: #ET time series that we have is not in the same format as the other variables, hence the different treatment
            [minplotDelta, maxplotDelta]=[50,50]
        #for tasmean, observed min and max T need to be converted into mean T
        elif Clim_var_type == 'tasmean':
            [minplotDelta, maxplotDelta]=[0.2,1]
        elif Clim_var_type == 'sstmean':
            [minplotDelta, maxplotDelta]=[40,40]
        elif Clim_var_type == 'tasmax':
            [minplotDelta, maxplotDelta]=[1,2]  
        elif Clim_var_type == 'wssmean' or  Clim_var_type == 'wss1Hmaxtstep':
            [minplotDelta, maxplotDelta]=[1, 1.5]  
        elif Clim_var_type == 'pracc':   
            [minplotDelta, maxplotDelta]=[50,100]
        elif Clim_var_type in ['rsdsmean', 'rldsmean']:   
            [minplotDelta, maxplotDelta]=[100,100]
            #[minplotDelta, maxplotDelta]=[1,1]
    #==========================================================#
    
     #substract a constant from all values to convert from kelvin to celcius (temp)
    if Clim_var_type == 'sstmean':
        #Present_day_df = Present_day_df.iloc[:,0:(len(Present_day_df)-1)]-273.15
        Present_day_df.index = Present_day_df.index.to_period('D')
    #==========================================================#
    #create seasonal sums etc. 
    #==========================================================#
    if Stats == 'maxdaily':
        Present_day_df_annual = Present_day_df.resample('A').max()
        Present_day_df_annual = Present_day_df_annual.replace(0, np.nan)
        Fdf_Seas_means = Present_day_df.resample('Q-NOV').max() #seasonal means
        Fdf_Seas_means = Fdf_Seas_means.replace(0, np.nan)
    elif Stats == 'maxmonthly':
        Present_day_df_annual = Present_day_df.resample('M').max().resample('A').mean()
        Present_day_df_annual = Present_day_df_annual.replace(0, np.nan)
        Fdf_Seas_means = Present_day_df.resample('M').max().resample('Q-NOV').mean() #seasonal means
        Fdf_Seas_means = Fdf_Seas_means.replace(0, np.nan)
    elif(Stats[:4] =='days'):
        Threshold = int(Stats[-2:])
        agg = ('>'+ str(Threshold) + '_count', lambda x: x.gt(Threshold).sum()),
        Present_day_df_annual = Present_day_df.resample('A').agg(agg)                
        Fdf_Seas_means = Present_day_df.resample('Q-NOV').agg(agg)  #seasonal means
    else:
        if Clim_var_type in ['pracc' ,'evspsblmean' ,'potevpmean' ,
                         'pr1Hmaxtstep' ,'wss1Hmaxtstep',
                         'rsdsmean', 'rldsmean']:
            Present_day_df_annual = Present_day_df.resample('A').sum()
            Present_day_df_annual = Present_day_df_annual.replace(0, np.nan)
            Fdf_Seas_means = Present_day_df.resample('Q-NOV').sum() #seasonal means
            Fdf_Seas_means = Fdf_Seas_means.replace(0, np.nan)
        elif Clim_var_type in ['tasmean' ,'tasmax' ,'sstmean']:    
            Present_day_df_annual = Present_day_df.resample('A').mean()
            Present_day_df_monthly = Present_day_df.resample('M').mean()
            Present_day_df_weekly = Present_day_df.resample('W').mean()
            Fdf_Seas_means = Present_day_df.resample('Q-NOV').mean() #seasonal means
    #==========================================================#
    
    #==========================================================# 
    #calculate linear trend in present day series
    #==========================================================#
    if Stats == 'maxdaily' or Stats[:4] =='days' or Stats == 'maxmonthly':
        coefficients, residuals, _, _, _ = np.polyfit(range(len(Present_day_df_annual.index)),Present_day_df_annual.values,1,full=True)
        #mse = residuals[0]/(len(selected.index))
        #nrmse = np.sqrt(mse)/(selected.max() - selected.min())
        trend = coefficients[0]
        print('Slope ' + str(coefficients[0]))
        print(Base_period_start[:4]+ '-' + Base_period_end[:4] + ' trend was: ' + str(np.round(trend,4)) + ' units/year')
    elif Stats == 'mean':
        coefficients, residuals, _, _, _ = np.polyfit(range(len(Present_day_df.index)),Present_day_df.values,1,full=True)
        #mse = residuals[0]/(len(selected.index))
        #nrmse = np.sqrt(mse)/(selected.max() - selected.min())
        if force_sea_levels == 'yes':
            trend = coefficients[0]*12
        else:
            trend = coefficients[0]*365
        print('Slope ' + str(coefficients[0]))
        print(Base_period_start[:4]+ '-' + Base_period_end[:4] + ' trend was: ' + str(np.round(trend,5)) + ' units/year')
        
    #==========================================================#
    
    
    #==========================================================#   
    #Loop through annual and seasons and create a deviation plot for each. 
    #==========================================================#
    times = ['annual', 'DJF', 'MAM', 'JJA','SON']
    fig = plt.figure(figsize=(14,8))
    delta_all_df = pd.DataFrame()
    Combined_Delta_df = pd.DataFrame()
    Combined_Med_df = pd.DataFrame()
    i=1
    for temp in times:
        #temp = 'annual'
        #subset the ensemble dataframe for the period used:
        if temp == 'annual':
            Ensemble_Delta_df = Ensemble_Delta_full_df.iloc[:,range(0,2)]
            Present_Day_ref_df = Present_day_df_annual
            Column_names = ['Annual_near', 'Annual_far']
        else:
            Ensemble_Delta_df = Ensemble_Delta_full_df.filter(regex= temp)
            Ensemble_Delta_df.columns = ['near', 'far']
            if temp == 'DJF':
                Mean_df = Fdf_Seas_means[Fdf_Seas_means.index.quarter==1]
                Column_names = ['Summer_near', 'Summer_far']
            if temp == 'MAM':
                Mean_df = Fdf_Seas_means[Fdf_Seas_means.index.quarter==2]
                Column_names = ['Autumn_near', 'Autumn_far']
            if temp == 'JJA':
                Mean_df = Fdf_Seas_means[Fdf_Seas_means.index.quarter==3]
                Column_names = ['Winter_near', 'Winter_far']
            if temp == 'SON':
                Mean_df = Fdf_Seas_means[Fdf_Seas_means.index.quarter==4]
                Column_names = ['Spring_near', 'Spring_far']
            Present_Day_ref_df = Mean_df  
        
        #Subset to present day variability period
        Present_Day_ref_df = pd.DataFrame(Present_Day_ref_df.loc[(Present_Day_ref_df.index >= Base_period_start) & (Present_Day_ref_df.index <= Base_period_end)])
        #Subset to present day variability delta base period (this is the statistical baseline used for present day conditions)
        Present_Day_Delta_ref_df = pd.DataFrame(Present_Day_ref_df.loc[(Present_Day_ref_df.index >= Base_period_DELTA_start) & (Present_Day_ref_df.index <= Base_period_end)])
        Present_Day_Mean = np.percentile(Present_Day_Delta_ref_df, 50)
        Present_Day_SD = np.std(Present_Day_Delta_ref_df)
        #create data frame for floating stacked barplots 
        index=['-2std', '-1std', 'Med', '1std', '2std']
        columns = ['present','near future', 'far future']
        Plot_in_df = pd.DataFrame(index=index, columns =columns)
        #  
        Plot_in_df['present'] = [float(Present_Day_Mean-2*Present_Day_SD),float(Present_Day_Mean-Present_Day_SD), float(Present_Day_Mean),
               float(Present_Day_Mean+Present_Day_SD), float(Present_Day_Mean+2*Present_Day_SD)]
        Plot_in_df['near future'] = [float(Present_Day_Mean + Ensemble_Delta_df.near[-3:][0]),np.NaN, float(Present_Day_Mean + Ensemble_Delta_df.near[-3:][1]), 
               np.NaN, float(Present_Day_Mean + Ensemble_Delta_df.near[-3:][2])]
        Plot_in_df['far future'] = [float(Present_Day_Mean + Ensemble_Delta_df.far[-3:][0]),np.NaN, float(Present_Day_Mean + Ensemble_Delta_df.far[-3:][1]), 
               np.NaN, float(Present_Day_Mean + Ensemble_Delta_df.far[-3:][2])]
        #Create a second data frame that has the values in a way that they can be stacked up in bars with the correct absolute values
        Plot_in_df2 = pd.DataFrame(index=index, columns =columns )
        #
        if presentdaybar == False:
            index=['-2std', '-1std', 'Med', '1std', '2std']
            columns = ['near future', 'far future']
            Plot_in_df2 = pd.DataFrame(index=index, columns =columns )
            #Plot_in_df2['present'] = [float(0),float(0), float(0),
            #              float(0), float(0)]  
        else:
            Plot_in_df2['present'] = [float(Present_Day_Mean-2*Present_Day_SD),float(Present_Day_SD), float(Present_Day_SD),
                    float(Present_Day_SD), float(Present_Day_SD)]
        Plot_in_df2['near future'] = [float(Present_Day_Mean + Ensemble_Delta_df.near[-3:][0]),np.NaN, float(Ensemble_Delta_df.near[-3:][1]-Ensemble_Delta_df.near[-3:][0]), 
              np.NaN, float(Ensemble_Delta_df.near[-3:][2]-Ensemble_Delta_df.near[-3:][1])]
        Plot_in_df2['far future'] = [float(Present_Day_Mean + Ensemble_Delta_df.far[-3:][0]),np.NaN, float(Ensemble_Delta_df.far[-3:][1]-Ensemble_Delta_df.far[-3:][0]), 
               np.NaN, float(Ensemble_Delta_df.far[-3:][2]-Ensemble_Delta_df.far[-3:][1])]
        #transpose the data frame
        Plot_in_df_tp = Plot_in_df2.transpose()
        #do the individual plots
        if temp == 'annual':
            xmin = int(min(Plot_in_df.min(axis=1))-minplotDelta)
            xmax = int(max(Plot_in_df.max(axis=1))+maxplotDelta)
        else:
            xmin = int(min(Plot_in_df.min(axis=1))-minplotDelta)
            xmax = int(max(Plot_in_df.max(axis=1))+maxplotDelta)
        #define colour scheme
        #likert_colors = ['none', 'firebrick','firebrick','lightcoral','lightcoral']
        likert_colors = ['none', 'darkblue', 'darkblue','cornflowerblue','cornflowerblue']
        uni_colors = ['none', 'cornflowerblue', 'cornflowerblue','cornflowerblue','cornflowerblue']
        #plot the stacked barplot
        if temp == 'annual':
            ax=plt.subplot(2,4,3) 
        else:
            ax=plt.subplot(2,4,i)  
        Plot_in_df_tp.plot.bar(stacked=True, color=uni_colors, edgecolor='none', legend=False, ax=ax, width=0.5)  
        df = pd.DataFrame(Plot_in_df.iloc[2,[1,2]])
        index2=['Med']
        columns2 = ['near future', 'far future']
        Plot_in_df3 = pd.DataFrame(index=index2, columns =columns2)
        Plot_in_df3['near future'] = df.iloc[1,0]
        Plot_in_df3['far future'] = df.iloc[0,0]
        Plot_in_df3 = Plot_in_df3.transpose()
#       plt.plot(Plot_in_df3['Med'], linestyle="", markersize=45, 
#             marker="_", color='red', label="Median")
        #Plot_in_df3['Med']
        #Plot_in_df3['Med'].values
        plt.plot(np.arange(2),Plot_in_df3['Med'].values[::-1], linestyle="", markersize=45, 
             marker="_", color='red', label="Median")
        z = plt.axhline(float(Present_Day_Mean-2*Present_Day_SD), linestyle='-', color='black', alpha=.5)
        z.set_zorder(-1)
        z = plt.axhline(float(Present_Day_Mean+2*Present_Day_SD), linestyle='-', color='black', alpha=.5)
        z.set_zorder(-1)
        z = plt.axhline(float(Present_Day_Mean-Present_Day_SD), linestyle='--', color='black', alpha=.5)
        z.set_zorder(-1)
        z = plt.axhline(float(Present_Day_Mean+Present_Day_SD), linestyle='--', color='black', alpha=.5)
        z.set_zorder(-1)
        z = plt.axhline(float(Present_Day_Mean), linestyle='--', color='red', alpha=.5)
        z.set_zorder(-1)
        plt.ylim(xmin, xmax)
        #plt.ylim(10, 140)
        if Figure_headings == 'yes':
            plt.title(Clim_var_type + ' ' + temp)
        ax.grid(False)
        for tick in ax.get_xticklabels():
            tick.set_rotation(0)
        fig.tight_layout()
        fig.patch.set_alpha(ALPHA_figs)
        #plt.set_facecolor('g')
                 
        if temp == 'annual':
            ax=plt.subplot(2,2,1) 
            Present_Day_ref_df.plot(legend=False, ax=ax)
            z = plt.axhline(float(Present_Day_Mean-2*Present_Day_SD), linestyle='-', color='black', alpha=.5)
            z.set_zorder(-1)
            z = plt.axhline(float(Present_Day_Mean+2*Present_Day_SD), linestyle='-', color='black', alpha=.5)
            z.set_zorder(-1)
            z = plt.axhline(float(Present_Day_Mean-Present_Day_SD), linestyle='--', color='black', alpha=.5)
            z.set_zorder(-1)
            z = plt.axhline(float(Present_Day_Mean+Present_Day_SD), linestyle='--', color='black', alpha=.5)
            z.set_zorder(-1)
            z = plt.axhline(float(Present_Day_Mean), linestyle='--', color='red', alpha=.5)
            z.set_zorder(-1)
            #fig.patch.set_facecolor('deepskyblue')
            fig.tight_layout()
            fig.patch.set_alpha(ALPHA_figs)
            if Figure_headings == 'yes':
                #plt.title(Clim_var_type)
                #plt.title(Clim_var_type + ' ' + Stats + ' ' + Base_period_start[:4] + '-' + Base_period_end[:4] + ' trend:' + str(np.round(trend,4)) + '/year')
                plt.title(Base_period_start[:4] + '-' + Base_period_end[:4] + ' trend:' + str(np.round(trend,4)) + '/year')
            plt.ylim(xmin, xmax)
            #plt.ylim(0, 40)
            ax.grid(False)
            #if temp == 'MAM':
            i=i+4
        else:
            i=i+1
        
        #create a data frame that contains all of the delta bars
        Plot_in_df_tp.index = Column_names
        Plot_in_df_tp['-2std'] = Plot_in_df_tp['-2std'] - Present_Day_Mean
        Combined_Delta_df = pd.concat([Combined_Delta_df, Plot_in_df_tp], axis=0)
        if Allin1_delta_plot == 'yes':
            ax=plt.subplot(2,4,4) 
            temp = Combined_Delta_df[0:2]
            Plot_in_df_tp = temp
            uni_colors = ['none', 'cornflowerblue', 'cornflowerblue','cornflowerblue','cornflowerblue']
            Plot_in_df_tp['Median'] = pd.DataFrame(Plot_in_df_tp['-2std'] + Plot_in_df_tp['Med'])
            if int(Plot_in_df_tp.stack().min(axis=None,skipna=True)) < 0:
                Bottom = int(Plot_in_df_tp.stack().min(axis=None,skipna=True)) -1
                Plot_in_df_tp['-2std'] = Plot_in_df_tp['-2std'] - Bottom
                Plot_in_df_tp.plot.bar(stacked=True, color=uni_colors, edgecolor='none', legend=False, width=0.5,ax=ax, bottom = Bottom)  
            else:
                Plot_in_df_tp.plot.bar(stacked=True, color=uni_colors, edgecolor='none', legend=False, width=0.5,ax=ax)
            if Median_markers == 'yes':
                plt.plot(np.arange(2),Plot_in_df_tp['Median'].values , linestyle="", markersize=45, 
                     marker="_", color='red', label="Median") 
            z = plt.axhline(float(0), linestyle='--', color='red', alpha=.5)
            z.set_zorder(-1)
            plt.ylim(Deltaxmin, Deltaymin)
            #plt.ylim(xmin, xmax)
            if Figure_headings == 'yes':
                plt.title(Clim_var_type + ' All Deltas ' + Stats)
            #ax.grid(False)
            ax.xaxis.grid(False)
            for tick in ax.get_xticklabels():
                tick.set_rotation(10)
            fig.tight_layout()
            fig.patch.set_alpha(ALPHA_figs)
        
    #plt.show()  
    if Main_Plot == 'yes': 
        if presentdaybar == False:
            out_file_name = Estuary  + '_' + Clim_var_type + '_' + Stats + '_'  + PD_Datasource +  '_'  + SILO_Clim_var[0] +  '_' + '_'  + Base_period_start +  '_'  + Base_period_end +  '_' +  Version +  '_'  + ' trend_' + str(np.round(trend[0],4)) + '.png'
        else:
            out_file_name = Estuary  + '_' + Clim_var_type + '_' + Stats + '_'  + PD_Datasource +  '_'  + SILO_Clim_var[0] +  '_' +  Version +  '_'  + '2.png'
        out_path = output_directory + '/' + out_file_name
        fig.savefig(out_path)
    plt.close(fig) 
    
    if Allin1_delta_plot == 'yes': 
        fig = plt.figure(figsize=(14,8))
        ax = fig.add_subplot(2, 3, 1)
        temp = Combined_Delta_df
        Plot_in_df_tp = temp
        uni_colors = ['none', 'cornflowerblue', 'cornflowerblue','cornflowerblue','cornflowerblue']
        Plot_in_df_tp['Median'] = pd.DataFrame(Plot_in_df_tp['-2std'] + Plot_in_df_tp['Med'])
        if int(Plot_in_df_tp.stack().min(axis=None,skipna=True)) < 0:
            Bottom = int(Plot_in_df_tp.stack().min(axis=None,skipna=True)) -1
            Plot_in_df_tp['-2std'] = Plot_in_df_tp['-2std'] - Bottom
            Plot_in_df_tp.plot.bar(stacked=True, color=uni_colors, edgecolor='none', legend=False, width=0.5,ax=ax, bottom = Bottom)  
        else:
            Plot_in_df_tp.plot.bar(stacked=True, color=uni_colors, edgecolor='none', legend=False, width=0.5,ax=ax)
        if Median_markers == 'yes':
#            plt.bar(Plot_in_df_tp.index, Plot_in_df_tp['Median'], linestyle="", markersize=13, 
#                     marker="_", color='red', label="Median") 
            plt.plot(np.arange(10), Plot_in_df_tp['Median'], linestyle="", markersize=13, 
                     marker="_", color='red', label="Median")
        z = plt.axhline(float(0), linestyle='--', color='red', alpha=.5)
        z.set_zorder(-1)
        plt.ylim(Deltaxmin, Deltaymin)
        if Figure_headings == 'yes':
            plt.title(Clim_var_type + ' All Delstas ' + Stats)
        #ax.grid(False)
        ax.xaxis.grid(False)
        for tick in ax.get_xticklabels():
            tick.set_rotation(50)
        plt.setp(ax.xaxis.get_majorticklabels(), ha='right')
        #ax.set_xticklabels(xticklabels, rotation = 45, ha="right")
        fig.tight_layout()
        fig.patch.set_alpha(ALPHA_figs)
        plt.show()
        #export plot to png
        out_file_name = Estuary  + '_' + Clim_var_type + '_' + Stats + '_'  + Base_period_start +  '_'  + Base_period_end +  '_'  +  Version + '_All_Deltas_In1.png'
        out_path = output_directory + '/' + out_file_name
        fig.savefig(out_path)
        plt.close(fig) 
        
##make  barplot with alternating colours       
#men_means, men_std = (20, 35, 30, 35, 27), (2, 3, 4, 1, 2)
#women_means, women_std = (25, 32, 34, 20, 25), (3, 5, 2, 3, 3)
#
#ind = np.arange(len(men_means))  # the x locations for the groups
#width = 0.35                     # the width of the bars
#
#fig, ax = plt.subplots()
#rects1 = ax.bar(ind - width/2, men_means, width, yerr=men_std,
#                color='SkyBlue', label='Men')
#rects2 = ax.bar(ind + width/2, women_means, width, yerr=women_std,
#                color='IndianRed', label='Women')
#
## Add some text for labels, title and custom x-axis tick labels, etc.
#ax.set_ylabel('Scores')
#ax.set_title('Scores by group and gender')
#ax.set_xticks(ind)
#ax.set_xticklabels(('G1', 'G2', 'G3', 'G4', 'G5'))
#ax.legend()
    
    if present_day_plot == 'yes':  
        #print present day climate data
            fig = plt.figure(figsize=(14,8))
            for i1 in range(2):
                if i1 ==0:
                    ax = fig.add_subplot(2, 3, 1)
                else:
                    ax = fig.add_subplot(2, 1, 2)
                xmin = int(min(Plot_in_df.min(axis=1))-minplotDelta)
                xmax = int(max(Plot_in_df.max(axis=1))+maxplotDelta)
                Present_Day_ref_df.plot(legend=False, ax=ax)
                z = plt.axhline(float(Present_Day_Mean-2*Present_Day_SD), linestyle='-', color='black', alpha=.5)
                z.set_zorder(-1)
                z = plt.axhline(float(Present_Day_Mean+2*Present_Day_SD), linestyle='-', color='black', alpha=.5)
                z.set_zorder(-1)
                z = plt.axhline(float(Present_Day_Mean-Present_Day_SD), linestyle='--', color='black', alpha=.5)
                z.set_zorder(-1)
                z = plt.axhline(float(Present_Day_Mean+Present_Day_SD), linestyle='--', color='black', alpha=.5)
                z.set_zorder(-1)
                z = plt.axhline(float(Present_Day_Mean), linestyle='--', color='red', alpha=.5)
                z.set_zorder(-1)
                #fig.patch.set_facecolor('deepskyblue')
                fig.patch.set_alpha(0)
                #plt.ylim(0, 400)
                plt.ylim(xmin, xmax)
                #export plot to png
            out_file_name = Estuary  + '_' + Clim_var_type + '_' + Stats + '_'  + Base_period_start +  '_'  + Base_period_end +  '_'  +  Version + 'Present_Day_Period.png'
            out_path = output_directory + '/' + out_file_name
            fig.savefig(out_path)
            plt.close(fig) 
            # use transparent=True if you want the whole figure with a transparent background
        
        
    
    
    
    
    
    
    
    