#R code for creating ggplots of time series with smooth (GAM) and linear term


######################
#Import Libraries and set working directory
######################
library(zoo)
library(hydroTSM) #you need to install these packages first before you can load them here
library(lubridate)
library(mgcv)
library(ggplot2)
library(gridExtra)
library(scales)
options(scipen=999)
setwd("C:/Users/z5025317/OneDrive - UNSW/WRL_Postdoc_Manual_Backup/WRL_Postdoc/Projects/Paper#1/")
######################

######################
#Set inputs
######################
Case.Study <- "CASESTUDY2"
Estuary <- "NADGEE"
Climvar <- 'tasmean'
ggplotGAM.k <- 7
######################


######################
Output.Directory <- paste('./Output/', Case.Study, '/', Estuary,'/Recent_Trends/', sep="")
if (file.exists(Output.Directory)){
  print('output folder already existed and was not created again')
} else {
  dir.create(file.path(Output.Directory))
  print('output folder did not exist and was created')
}
######################


######################
#Set input file paths
######################
AirT_CSV_Path <- paste("./Data/Ocean_Data/BOM_monthly_SL_",Estuary,  "_Eden.txt", sep="")


dat = readLines(AirT_CSV_Path)
dat = as.data.frame(do.call(rbind, strsplit(dat, split=" {2,10}")), stringsAsFactors=FALSE)
colnames(dat) <-dat[3,]

if (Estuary=='NADGEE'){
  dat2 = dat[-c(1:11), ] 
  dat2 = dat2[-(365:381),]
  dat2 = dat2[,-1]
  }

if (Estuary=='HUNTER'){
  dat2 = dat[-c(1:3), ]  
  dat2 = dat2[-(720:726),]
  dat2 = dat2[-(1:108),]
  dat2 = dat2[,-1]
  }



dat2$Date <-  as.yearmon(dat2[,1], "%m %Y")

SeaLev.df <- dat2
head(SeaLev.df)
SeaLev.df$MSL <- as.numeric(SeaLev.df$Mean)

#rid of outliers
SeaLev.df$MSL <- replace(SeaLev.df$MSL, which(SeaLev.df$MSL > 4), NA)
  
SeaLev.df$Julday1 <- seq(1,length(SeaLev.df[,1]),1)
linear.trend.model_EC_all <- lm(MSL ~ Julday1, SeaLev.df)
SeaLev.pvalNCV_ECall <- summary(linear.trend.model_EC_all )$coefficients[2,4] 
SeaLev.lintrend <- summary(linear.trend.model_EC_all )$coefficients[2,1] * 12



######################
#Plot
######################

##################################### Full Time Period
p1air <- ggplot(SeaLev.df, aes(y=MSL, x=Date)) + geom_line(alpha=0.5) + 
  ggtitle(paste(Estuary, " - Linear and smooth trend in monthly mean sea level (BOM Gauge) | lin trend was ",
                round(100*SeaLev.lintrend,3), ' cm/year with p=', round(SeaLev.pvalNCV_ECall,10), sep=" ")) +
  theme(plot.title=element_text(face="bold", size=9)) +
  geom_smooth(method='lm',fill="green", formula=y~x, colour="darkgreen", size = 0.5) +
  stat_smooth(method=gam, formula=y~s(x,  k=4), se=T, size=0.5, col="red") +
  ylab("Monthly Mean Sea Level [m]") + xlab("Time")

#export to png
png.name <- paste(Output.Directory, '/Trends_MonthlyMeanSeaLevel_full_period_', Sys.Date(),".png", sep="")
png(file = png.name, width = 10.5, height = 7, units='in', res=500)
grid.arrange(p1air,ncol=1)
dev.off()

#multiple smooths
p1air <- ggplot(SeaLev.df, aes(y=MSL, x=Date)) + geom_line(alpha=0.5) + 
  ggtitle(paste(Estuary, " - Linear and smooth trend in monthly mean sea level (BOM Gauge) | lin trend was ",
                round(100*SeaLev.lintrend,3), ' cm/year with p=', round(SeaLev.pvalNCV_ECall,10), sep=" ")) +
  theme(plot.title=element_text(face="bold", size=9)) +
  stat_smooth(method=gam, formula=y~s(x,  k=13), se=T, size=0.5, col="red") +
  #stat_smooth(method=gam, formula=y~s(x,  k=8), se=T, size=0.5, cor="blue") +
  stat_smooth(method=gam, formula=y~s(x,  k=5), se=T, size=0.5, col="green") +
  ylab("Monthly Mean Sea Level [m]") + xlab("Time")

#export to png
png.name <- paste(Output.Directory, '/Trends_MonthlyMeanSeaLevel_MultiGAM_full_period_', Sys.Date(),".png", sep="")
png(file = png.name, width = 10.5, height = 7, units='in', res=500)
grid.arrange(p1air,ncol=1)
dev.off()
